#!/bin/sh
#
#	This file is executed by init(8) when the system is being
#	initialized for one of the "multi user" run levels (i.e.
#	levels 1 through 6).  
#
# /etc/rc.d/rc.M: 

## bootsplash
. /etc/rc.d/rc.bootsplash

# Tell the viewers what's going to happen:
progressbar 21
echo -en "\\033[1;33m"
echo "Going multiuser."
echo -en "\\033[1;37m"

# Screen blanks after 0-60 minutes idle time.
# To turn speaker beep off: -bfreq 0
if [ -x /bin/setterm ]; then
progressbar 23
/bin/setterm -blank 60 -powersave on
fi

# Look for a CD-ROM in a CD-ROM drive, if one is found
# mount it under /mnt/cdrom.
#if [ -x /etc/rc.d/rc.cdrom ]; then
progressbar 24
#/etc/rc.d/rc.cdrom
#fi

# If there's no /etc/HOSTNAME, fall back on this default:
if [ ! -s /etc/HOSTNAME ]; then
progressbar 25
echo "aLinux.alinux.tv" > /etc/HOSTNAME
fi

# Set the hostname from the /etc/HOSTNAME file. 
if [ -x /bin/hostname ]; then
progressbar 26
/bin/hostname `cat /etc/HOSTNAME | cut -f1 -d .`
fi

if [ -x /usr/sbin/syslogd ]; then
echo "Starting system log daemon: syslogd: syslogd -m 0"
progressbar 29
/usr/sbin/syslogd -m 0
echo "Starting kernel log daemon: klogd -c 1 -2"
progressbar 30
/usr/sbin/klogd -c 1 -2
fi

# Start netatalk. (a file/print server for Macs using Appletalk)
#if [ -x /etc/rc.d/rc.atalk ]; then
progressbar 34
#/etc/rc.d/rc.atalk
#fi

# Start crond (Dillon's crond):
# If you want cron to actually log activity to /var/adm/cron, then change
# -l10 to -l8 to increase the logging level.
if [ -x /usr/sbin/crond ]; then
echo "Starting cron daemon: crond -l8"
progressbar 35
/usr/sbin/crond -l8 >>/var/adm/cron 2>&1
fi

# Start atd (manages jobs scheduled with 'at'):
if [ -x /usr/sbin/atd ]; then
echo "Starting at daemon: atd -b 15 -l 1"
progressbar 36
/usr/sbin/atd -b 15 -l 1
fi

# Remove stale files (must be done after mount -a!)
progressbar 37
/bin/rm -f /var/lock/LCK* /var/spool/uucp/LCK*
progressbar 38
/bin/rm -rf 2>/dev/null /tmp/.* /tmp/* /var/tmp/.* /var/tmp/*

# Create /tmp directory if it doesn't exist.
if [ ! -d /tmp ]; then
progressbar 39
mkdir /tmp
fi

# Ensure basic filesystem permissions sanity.
progressbar 40
chmod 755 / 2>/dev/null
progressbar 41
chmod 1777 /tmp /var/tmp 2>/dev/null

# Update all the shared library links automatically
progressbar 42
#/sbin/ldconfig

# Slackware-Mini-Quota-HOWTO:
# To really activate quotas, you'll need to add 'usrquota' to the appropriate
# partitions as listed in /etc/fstab.  Here's an example:
# /dev/hda2   /home   ext2   defaults,usrquota    1   1
# You'll then need to setup initial quota files at the top of the partitions
# to support quota, like this:
# touch /home/quota.user /home/quota.group
# chmod 600 /home/quota.user /home/quota.group
# Then, reboot to activate the system.
# To edit user quotas, use 'edquota'.  See 'man edquota'.  Also, the
# official Quota Mini-HOWTO has lots of useful information.  That can be found
# here:  ftp://ftp.cdrom.com/pub/linux/slackware/docs/mini/Quota

# Check quotas and then turn quota system on:
#if grep -F quota /etc/fstab 1> /dev/null 2> /dev/null ; then
#if [ -x /sbin/quotacheck ]; then
#echo "Checking filesystem quotas"
progressbar 43
#/sbin/quotacheck -avug
#fi
#if [ -x /sbin/quotaon ]; then
#echo "Activating filesystem quotas: quotacheck -avug"
#progressbar 44
#/sbin/quotaon -avug
#fi
#fi

# Check for first time swap file and then turn it on system:
if [ -f /mnt/swap/swap.img.bz2 ]; then
echo "Starting a 512 Mb swap: /mnt/swap/swap.txt"
progressbar 45
/usr/bin/bunzip2 /mnt/swap/swap.img.bz2; /sbin/swapon -a 1> /dev/null 2> /dev/null
fi

# Start the sendmail daemon:
if [ -x /usr/sbin/sendmail ]; then
echo "Starting sendmail daemon: sendmail -bd -q15m"
progressbar 46
/usr/sbin/sendmail -bd -q15m
fi

# Start Xft2 font cache:
if [ -x /usr/X11R6/bin/fc-cache ]; then
echo "Starting Xorg/XFree86 font cache: /usr/X11R6/bin/fc-cache"
progressbar 48
/usr/X11R6/bin/fc-cache
fi

# Start GNOME Fire starter - FireWall protection..
if [ -x /etc/firestarter/firewall.sh ]; then
echo "Starting FireWall/IPTables: /etc/firestarter/firewall.sh"
progressbar 49
/etc/firestarter/firewall.sh
fi

# Typematic Rate:
if [ -x /sbin/kbdrate ]; then
echo "Starting Keyboard Console repeat rate: /sbin/kbdrate -r 30.0 -d 250"
progressbar 50
/sbin/kbdrate -r 30.0 -d 250
fi

# Start 'XFS' True Type Font Server
if [ -x /usr/X11R6/bin/xfs ]; then
echo "Starting Xorg/XFree86 font daemon: xfs -config /etc/X11/fs/config -daemon"
progressbar 51
/usr/X11R6/bin/xfs -config /etc/X11/fs/config -daemon
fi

# Start ACPI daemon 'acpid' for newer laptop computers.
if [ -f /proc/acpi/event -a -x /usr/sbin/acpid ]; then
echo "Starting ACPI daemon: /usr/sbin/acpid"
progressbar 52
/usr/sbin/acpid
fi

# Start APM daemon 'apmd' for older laptop computers.
if [ -f /proc/apm -a -x /usr/sbin/apmd ]; then
echo "Starting APM daemon: /usr/sbin/apmd"
progressbar 52
/usr/sbin/apmd
fi

# Start the DBUS Hardware daemon.
if [ -x /usr/bin/dbus-daemon ]; then
echo "Starting DBUS daemon: dbus-daemon --system"
progressbar 53
/usr/bin/dbus-daemon --system
/usr/bin/dbus-uuidgen --ensure
fi

# Start the HAL Hardware daemon.
if [ -x /usr/sbin/hald ]; then
echo "Starting HAL daemon: hald --daemon=yes"
progressbar 53
/usr/sbin/hald --daemon=yes
echo /sbin/udevsend >/proc/sys/kernel/hotplug
fi

# Start the POLICY-KIT Hardware daemon.
if [ -x /usr/sbin/polkitd ]; then
echo "Starting POLICY-KIT daemon: /usr/sbin/polkitd"
progressbar 54
/usr/sbin/polkitd
fi

# Start the IVMAN Hardware daemon.
#if [ -x /usr/bin/ivman ]; then
#echo "Starting IVMAN daemon: /usr/bin/ivman"
#/usr/bin/ivman
#fi

# If there are SystemV init scripts for this runlevel, run them.
if [ -x /etc/rc.d/rc.sysvinit ]; then
echo "Starting SystemV init scripts: /etc/rc.d/rc.sysvinit"
progressbar 55
/etc/rc.d/rc.sysvinit &>/dev/null
fi

# Initialize the NET subsystem.
if [ -x /etc/rc.d/rc.inet1 ]; then
echo "Initializing the NET1 subsystem: /etc/rc.d/rc.inet1 start"
progressbar 56
/etc/rc.d/rc.inet1 start
fi

# If we see IPv4 packet forwarding support in the kernel, we will turn it on.
# This was the default for 2.0.x kernels, but with recent kernels it must be
# activated through a file in /proc.  IPv4 packet forwarding support is 
# required if you plan to use your aLinux machine as a router or firewall.
# If you don't want your aLinux machine to forward packets, change the 1 below
# to a 0.
IPV4_FORWARD=1
if [ -f /proc/sys/net/ipv4/ip_forward ]; then
  if [ "$IPV4_FORWARD" = "1" ]; then
    echo 1 > /proc/sys/net/ipv4/ip_forward
  else
    echo 0 > /proc/sys/net/ipv4/ip_forward
  fi
fi

# When using IPv4 packet forwarding, you will also get the rp_filter, which
# automatically rejects incoming packets if the routing table entry for their
# source address doesn't match the network interface they're arriving on.  This
# has security advantages because it prevents the so-called IP spoofing,
# however it can pose problems if you use asymmetric routing (packets from you
# to a host take a different path than packets from that host to you) or if
# you operate a non-routing host which has several IP addresses on different
# interfaces.  To turn rp_filter off, uncomment the lines below:
# if [ -r /proc/sys/net/ipv4/conf/all/rp_filter ]; then
#   echo "Disabling rp_filter..."
#   echo 0 > /proc/sys/net/ipv4/conf/all/rp_filter
# fi

# Start the SUN RPC Portmapper:
if [ -x /sbin/rpc.portmap ]; then
echo "Starting RPC Portmapper: /sbin/rpc.portmap"
progressbar 57
/sbin/rpc.portmap
fi

# At this point, we are ready to talk to The World...
# Export NFS shares: Add your shares to /etc/exports.
if [ -x /usr/sbin/exportfs ]; then
echo "Starting NFS sharing: /usr/sbin/exportfs -ra"
progressbar 58
/usr/sbin/exportfs -ra
fi

# Start the INET:
if [ -x /usr/sbin/inetd ]; then
echo "Starting INET SuperServer: /usr/sbin/inetd"
progressbar 59
/usr/sbin/inetd
fi

# Start DSL service if available:
if [ -f /etc/ppp/rp-pppoe-gui/passwd ]; then
echo "Roaring Penguin DSL detected"
else
if [ -f /etc/ppp/pppoe.conf-bak ]; then
echo "DSL detecting: /usr/sbin/pppoe-start"
/usr/sbin/pppoe-start
fi
fi

if [ -x /usr/sbin/mdnsd ]; then
echo "Starting mDNSResponder: /usr/sbin/mdnsd"
/usr/sbin/mdnsd
progressbar 60
touch /var/lock/subsys/mdnsd
fi

# Start NFS Server
if [ -x /usr/sbin/rpc.nfsd ]; then
echo "Starting NFS services: /usr/sbin/{rpc.nfsd 4,rpc.mountd,rpc.statd}"
progressbar 61
/usr/sbin/rpc.nfsd 4
/usr/sbin/rpc.mountd
/usr/sbin/rpc.statd
fi

# Start SAMBA Server
if [ -x /usr/sbin/smbd ]; then
echo "Starting SAMBA file/print services: /usr/sbin/{smbd,nmbd -D}"
progressbar 62
/usr/sbin/smbd -D
/usr/sbin/nmbd -D
fi

# Load a custom screen font if the user has an rc.font script.
if [ -x /etc/rc.d/rc.font ]; then
echo "Loading the custom screen console font: /etc/rc.d/rc.font"
progressbar 63
/etc/rc.d/rc.font
fi

# Load a custom keymap if the user has an rc.keymap script.
if [ -x /etc/rc.d/rc.keymap ]; then
echo "Loading the custom keymapper: /etc/rc.d/rc.keymap"
progressbar 64
/etc/rc.d/rc.keymap
fi

# iBCS Emulation for Linux
# The Intel Binary Compatibility Specification, or iBCS, specifies the
# interfaces between application programs and the surrounding operating
# system environment for i386 based systems. There are however several
# flavours of iBCS in use - SVR4, SVR3 plus several vendor specific
# extensions to SVR3 which are slightly different and incompatible. The
# iBCS emulator for Linux supports all flavours known so far.
#if [ -x /etc/rc.d/rc.ibcs2 ]; then
progressbar 65
#/etc/rc.d/rc.ibcs2
#fi

# Start the OpenSLP daemon:
if [ -x /usr/sbin/slpd ]; then
echo "Starting openslp daemon: slpd"
progressbar 66
/usr/sbin/slpd
fi

# Start GPM mouse driver.
# If you have a ps2 mouse put: -t ps2 -m /dev/mouse; Wheel mouse -t imps2.
if [ -x /usr/bin/gpm ]; then
echo "Starting mouse driver: gpm -m /dev/mouse -t ps2 -r 30"
progressbar 67
/usr/bin/gpm -m /dev/mouse -t ps2 -r 30
fi

# Start Lisa - OpenLDAP LAN.
if [ -x /opt/kde/bin/lisa ]; then
progressbar 69
/opt/kde/bin/lisa &>/dev/null
fi

# Start SLAPD - OpenLDAP LAN: SEE /etc/openldap;
if [ -x /usr/bin/slapd  ]; then
progressbar 70
/usr/bin/slapd &>/dev/null
fi

# Start one time only the auto Xorg / XFree86 configuration script.
if [ ! -s /etc/X11/XF86Config-4 ]; then
progressbar 75
/usr/X11/bin/X -configure 1>/dev/null 2>/dev/null
mv /xorg.conf.new /etc/X11/XF86Config-4 1>/dev/null 2>/dev/null
mouseconfig --kickstart --modifyx 1>/dev/null 2>/dev/null
echo -e "Section \"DRI\"
    Mode 0666
EndSection" >>/etc/X11/xorg.conf
else
progressbar 78
cat /etc/X11/XF86Config-4 | grep BoardName
fi

# Start the MySQL/FTP/HTTP Daemon(s). Telnet Daemon is started by /etc/inetd.conf.
if [ -x /home/xitami ]; then
echo "*************************************"
echo "*     T E L N E T - D A E M O N     *"
echo "*        F T P - D A E M O N        *"
echo "*       H T T P - D A E M O N       *"
echo "*        N F S - D A E M O N        *"
echo "*      S A M B A - D A E M O N      *"
echo "*      PHP/MySQL - D A E M O N      *"
echo "*       L I S A - D A E M O N       *"
echo "*      S L A P D - D A E M O N      *"
echo "*        S S H - D A E M O N        *"
echo "*************************************"
cd /home
progressbar 80
/home/xitami -s &>/dev/null
fi

# Start lpd daemon:
#if [ -x /usr/sbin/lpd ]; then
#echo "Starting printer daemon: lpd"
progressbar 85
#/usr/sbin/lpd
#fi

# Start printer daemon:
if [ -x /usr/sbin/cupsd ]; then
echo "Starting printer daemon: cupsd"
progressbar 88
MAKEDEV lp; /usr/sbin/cupsd
fi

# Start the local setup procedure.
if [ -x /etc/rc.d/rc.local ]; then
progressbar 90
/etc/rc.d/rc.local
fi

# Starts the Linux logo. Try leaving this file as the last startup command.
if [ -x /usr/bin/ty2h9 ]; then
progressbar 100
killall -9 -q -2 fbmngplay 2>/dev/null
/usr/bin/ty2h9 -c -yut "Your into aL i n u x  O P E R A T I N G  S Y S T E M"
fi

# All done.
