#!/bin/sh
#
# System initialization script.
#
# /etc/rc.d/rc.S: 
PATH=/sbin:/usr/sbin:/bin:/usr/bin

# Mount /proc and /sys right away:
/bin/mount -v proc /proc -n -t proc
/bin/mount -v sysfs /sys -n -t sysfs

# Enable UDEV:
if [ -x /etc/rc.d/rc.udev ]; then
echo "Starting UDEV: /etc/rc.d/rc.udev"
/etc/rc.d/rc.udev start
fi

# Test to see if the root partition is read-only for a ext2 filesystem.
READWRITE=no
if echo -n >> "Testing filesystem status"; then
rm -f "Testing filesystem status"
 READWRITE=yes
fi

# Check the integrity of all filesystems:
if [ ! $READWRITE = yes ]; then
echo "Filesystem check: /sbin/fsck -sVCyt reiser4,reiserfs,ext4,ext3,ext2,vfat,msdos,minix,xfs"
/sbin/fsck -sVCyt reiser4,reiserfs,ext4,ext3,ext2,vfat,msdos,minix,xfs $fsckoptions
fi

echo "Remounting root device with read-write enabled."
/bin/mount -w -v -n -o remount /

# Any /etc/mtab that exists here is old, so we delete it to start over:
/bin/rm -f /etc/mtab*
# Remounting the / partition will initialize the new /etc/mtab to udev:
/bin/mount -w -o remount /

# Fix /etc/mtab to list sys and proc if they were not yet entered in
# /etc/mtab because / was still mounted read-only:
if [ -d /proc/sys ]; then
  /bin/mount -f proc /proc -t proc
fi
if [ -d /sys/bus ]; then
  /bin/mount -f sysfs /sys -t sysfs
fi
if [ -f /sys/power/state ]; then
  /bin/chmod 666 /sys/power/state
fi

# Mount file systems in /etc/fstab (and create an entry for /)
# but not NFS or SAMBA because TCP/IP is not yet configured.
/bin/mount -avt nonfs,nosmbfs,noproc,nosysfs
if [ -x /bin/mkfifo ]; then
  /bin/mkfifo -m 600 /dev/xconsole
fi

# Check for bootsplash resolution:
. /etc/rc.d/rc.bootsplash
progressbar 1
if [ -e /dev/fb0 ]; then
if grep -F 640x480 /proc/splash 1> /dev/null 2> /dev/null ; then
    fbmngplay -x 280 -y 405 /etc/bootsplash/themes/fb-aLinux/animations/anim.mng &
elif grep -F 800x600 /proc/splash 1> /dev/null 2> /dev/null ; then
    fbmngplay -x 342 -y 505 /etc/bootsplash/themes/fb-aLinux/animations/anim.mng &
elif grep -F 1024x768 /proc/splash 1> /dev/null 2> /dev/null ; then
    fbmngplay -x 440 -y 650 /etc/bootsplash/themes/fb-aLinux/animations/anim.mng &
elif grep -F 1280x1024 /proc/splash 1> /dev/null 2> /dev/null ; then
    fbmngplay -x 550 -y 862 /etc/bootsplash/themes/fb-aLinux/animations/anim.mng &
    fi
fi

# Shows the bootup banner.
echo -en "\t\t\tWelcome to "
[ "$BOOTUP" != "serial" ] && echo -en "\\033[1;33m"
echo -e "aLinux.alinux.tv"
[ "$BOOTUP" != "serial" ] && echo -en "\\033[0;39m"
progressbar 2

# Enable swapping:
if [ -x /sbin/swapon ]; then
progressbar 3
echo "Enabling swap: /sbin/swapon -a 2>/dev/null"
/sbin/swapon -a 2>/dev/null
fi

# Remove any pids in /var/run.
progressbar 11
/bin/rm -f /var/run/{*pid,*/*pid}

# Start Name Switch Cache Daemon:
if [ -x /usr/sbin/nscd ]; then
progressbar 12
echo "Starting Name Switch Cache Daemon: /usr/sbin/nscd"
/usr/sbin/nscd
fi

if [ -f /var/run/wtmp ]; then
echo "/var/run/wtmp; looks good."
else
touch /var/log/wtmp 2>/dev/null
fi

# Remove contents of /var/run/utmp.
progressbar 13
cat /dev/null >/var/run/utmp

# Configure the system clock. Set system time from BIOS time.
if [ -x /sbin/hwclock ]; then
echo "Configure the system clock from BIOS time: /sbin/hwclock --hctosys"
progressbar 14
/sbin/hwclock --hctosys
fi

if [ -f /lib/modules/`uname -r`/modules.dep ]; then
progressbar 15
else
echo "New kernel version `uname -r` found. Updating database."
/sbin/depmod -a
fi

# Setup the /etc/issue and /etc/motd to reflect the current kernel level:
# THESE WIPE ANY CHANGES YOU MAKE TO /ETC/ISSUE AND /ETC/MOTD WITH EACH
# BOOT. COMMENT THEM OUT IF YOU WANT TO MAKE CUSTOM VERSIONS.
echo "Welcome to aLinux.alinux.tv Kernel `uname -r` (\d) (\t) \l" > /etc/issue
echo >> /etc/issue
echo "aLinux.alinux.tv Kernel `uname -r`" > /etc/motd
progressbar 16

# If you have a PNP modem or any PNP device, you may need to use pnpdump 
# and isapnp to get it setup.
#
# pnpdump -c > /etc/isapnp.conf           <Create /etc/isapnp.conf file>
# isapnp /etc/isapnp.conf
#
# Read the docs in /usr/doc/isapnptools.
# pnpdump isapnp isapnp.conf   <Man pages>
#if [ -x /sbin/isapnp -a -s /etc/isapnp.conf ]; then
progressbar 17
#/sbin/isapnp /etc/isapnp.conf
#fi

# This loads any kernel modules that are needed. These might be required to
# use your CD-ROM drive, bus mouse, ethernet card, or other optional hardware.
# Look at the /etc/rc.d/rc.modules file for modules to load.
if [ -x /etc/rc.d/rc.modules ]; then
echo "Loading any required kernel modules: /etc/rc.d/rc.modules"
progressbar 18
/etc/rc.d/rc.modules
fi

# Initialize PCMCIA devices:
#if [ -x /etc/rc.d/rc.pcmcia ]; then
#echo "Initializing PCMCIA devices: /etc/rc.d/rc.pcmcia start"
progressbar 19
#/etc/rc.d/rc.pcmcia start
#fi

# Run serial port setup script:
# (CAREFUL! This can make some systems hang if the rc.serial script isn't
# set up correctly. If this happens, you may have to edit the file from a
# boot disk)
#
# Run 'comset' to create a /etc/rc.d/rc.serial for your modem device.
# comset
if [ -x /etc/rc.d/rc.serial ]; then
echo "Starting PPP modem services: /etc/rc.d/rc.serial"
progressbar 20
/etc/rc.d/rc.serial
fi
